"""
utils module (imdb package).

This module provides basic utilities for the imdb package.

Copyright 2004 Davide Alberani <davide.alberani@erlug.linux.it>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""

import types


# The URLs of the "main details", "combined details" and "plot summary" pages.
imdbURL_main = 'http://akas.imdb.com/title/tt%s/'
imdbURL_combdet = 'http://akas.imdb.com/title/tt%s/combined'
imdbURL_plot = 'http://akas.imdb.com/title/tt%s/plotsummary'


def mixIn(pyClass, mixInClass, makeAncestor=0):
    """Function used to "mix-in" two classes.
    
    This code is taken from the Chuck Esterbrook's famous article
    "Using Mix-ins with Python" published by "Linux Journal", which
    can be found on-line at http://www.linuxjournal.com/article.php?sid=4540
    """
    if makeAncestor:
        if mixInClass not in pyClass.__bases__:
            pyClass.__bases__ = (mixInClass,) + pyClass.__bases__
    else:
        # Recursively traverse the mix-in ancestor
        # classes in order to support inheritance
        baseClasses = list(mixInClass.__bases__)
        baseClasses.reverse()
        for baseClass in baseClasses:
            mixIn(pyClass, baseClass)
        # Install the mix-in methods into the class
        for name in dir(mixInClass):
            if not name.startswith('__'):
                # skip private members
                member = getattr(mixInClass, name)
                if type(member) is types.MethodType:
                    member = member.im_func
                setattr(pyClass, name, member)


